<?php


/**
* Portfolio Register
*/
class WPDaddyPortfolioRegister{

	public $cpt;
	public $dest_taxonomy;
    private $tag_taxonomy;
	private $slug;
	
	function __construct(){
		$this->cpt = 'portfolio';
		$this->taxonomy = 'portfolio-category';
        $this->tag = 'portfolio-tag';
		$this->slug =  'portfolio-posts';
        if (function_exists('oswald_option')) {
            $slug_option = oswald_option('portfolio_slug');
        }else{
            $slug_option = '';
        }

        if (empty($slug_option)) {
            $this->slug = 'portfolio-posts';
        }else{
            $this->slug = sanitize_title( $slug_option );
        }
	}

	public function register(){
		$this->registerPostType();
		$this->registerTax();         
	}

	private function registerPostType(){

        register_post_type($this->cpt,
            array(
                'labels' 		=> array(
                    'name' 				=> __('Portfolio','wpdaddy_core' ),
                    'singular_name' 	=> __('Portfolio','wpdaddy_core' ),
                    'add_item'			=> __('New Portfolio','wpdaddy_core'),
                    'add_new_item' 		=> __('Add New Portfolio','wpdaddy_core'),
                    'edit_item' 		=> __('Edit Portfolio','wpdaddy_core')
                ),
                'public'		=>	true,
                'has_archive' => true,
                'rewrite' 		=> 	array('slug' => $this->slug),
                'menu_position' => 	5,
                'show_ui' => true,
                'supports' => array( 'title', 'editor', 'thumbnail', 'excerpt', 'page-attributes','comments'),
                'menu_icon'  =>  'dashicons-format-gallery'
            )
        );

	}

	private function registerTax() {
        $labels = array(
            'name' => __( 'Portfolio Categories', 'wpdaddy_core' ),
            'singular_name' => __( 'Portfolio Category', 'wpdaddy_core' ),
            'search_items' =>  __( 'Search Portfolio Categories','wpdaddy_core' ),
            'all_items' => __( 'All Portfolio Categories','wpdaddy_core' ),
            'parent_item' => __( 'Parent Portfolio Category','wpdaddy_core' ),
            'parent_item_colon' => __( 'Parent Portfolio Category:','wpdaddy_core' ),
            'edit_item' => __( 'Edit Portfolio Category','wpdaddy_core' ),
            'update_item' => __( 'Update Portfolio Category','wpdaddy_core' ),
            'add_new_item' => __( 'Add New Portfolio Category','wpdaddy_core' ),
            'new_item_name' => __( 'New Portfolio Category Name','wpdaddy_core' ),
            'menu_name' => __( 'Categories','wpdaddy_core' ),
        );

        register_taxonomy($this->taxonomy, array($this->cpt), array(
            'hierarchical' => true,
            'labels' => $labels,
            'show_ui' => true,
            'show_admin_column' => true,
            'query_var' => true,
            'rewrite' => array( 'slug' => $this->slug.__('-category','wpdaddy_core') ),
        ));

        $labels = array(
            'name' => __( 'Portfolio Tags', 'wpdaddy_core' ),
            'singular_name' => __( 'Portfolio Tag', 'wpdaddy_core' ),
            'search_items' =>  __( 'Search Portfolio Tags','wpdaddy_core' ),
            'all_items' => __( 'All Portfolio Tags','wpdaddy_core' ),
            'parent_item_colon' => __( 'Parent Portfolio Tag:','wpdaddy_core' ),
            'edit_item' => __( 'Edit Portfolio Tag','wpdaddy_core' ),
            'update_item' => __( 'Update Portfolio Tag','wpdaddy_core' ),
            'add_new_item' => __( 'Add New Portfolio Tag','wpdaddy_core' ),
            'new_item_name' => __( 'New Portfolio Tag Name','wpdaddy_core' ),
            'menu_name' => __( 'Tags','wpdaddy_core' ),
        );

        register_taxonomy($this->tag, array($this->cpt), array(
            'hierarchical' => true,
            'labels' => $labels,
            'show_ui' => true,
            'show_admin_column' => true,
            'query_var' => true,
            'rewrite' => array( 'slug' => $this->slug.__('-tag','wpdaddy_core') ),
        ));
    }

    public function registerSingleTemplate($single){
        global $post;
        if(!empty($post) && $post->post_type == $this->cpt) {
            if(!file_exists(get_template_directory().'/single-'.$this->cpt.'.php')) {
                return plugin_dir_path( dirname( __FILE__ ) ) .'portfolio/templates/single-'.$this->cpt.'.php';
            }
        }
        return $single;  
    }

    public function registerArchiveTemplate($archive){
        global $post;

        if(!empty($post) && $post->post_type == $this->cpt && is_archive()) {
            if(!file_exists(get_template_directory().'/archive-'.$this->cpt.'.php')) {
                return plugin_dir_path( dirname( __FILE__ ) ) .'portfolio/templates/archive-'.$this->cpt.'.php';
            }
        }

        return $archive;  
    }

}
?>