<?php

/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              https://wpdaddy.com/
 * @since             1.0.0
 * @package           wpdaddy_core
 *
 * @wordpress-plugin
 * Plugin Name:       Oswald Pro Plugin
 * Plugin URI:        https://wpdaddy.com/
 * Description:       Core plugin for Oswald Theme.
 * Version:           1.0.9.3
 * Author:            Wpdaddy
 * Author URI:        https://wpdaddy.com/
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       wpdaddy_core
 * Domain Path:       /languages
 */


// If this file is called directly, abort.
if ( ! defined( 'WPINC' )  ) {
	die;
}

$theme = wp_get_theme();
if ($theme->get('Name') !== 'Oswald' // Name
    && $theme->get('Template') !== 'oswald' // Child Theme
) {
    return;
}


define( 'OSWALD_PRO_PLUGIN_DIR', untrailingslashit( plugin_dir_path( __FILE__ ) ) );

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-wpdaddy_core-activator.php
 */
function activate_wpdaddy_core() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-wpdaddy_core-activator.php';
	wpdaddy_core_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-wpdaddy_core-deactivator.php
 */
function deactivate_wpdaddy_core() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-wpdaddy_core-deactivator.php';
	wpdaddy_core_Deactivator::deactivate();
}

register_activation_hook( __FILE__, 'activate_wpdaddy_core' );
register_deactivation_hook( __FILE__, 'deactivate_wpdaddy_core' );

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path( __FILE__ ) . 'includes/class-wpdaddy_core.php';


/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
function run_wpdaddy_core() {

	$plugin = new wpdaddy_core();
	$plugin->run();

}
run_wpdaddy_core();

if (!function_exists('oswald_pro_plugins_loaded')) {
	function oswald_pro_plugins_loaded(){
		require_once (plugin_dir_path( __FILE__ ).'/includes/customizer/class-oswald-customizer.php');	
	}
	add_action('plugins_loaded', 'oswald_pro_plugins_loaded');
}

if ( ! defined( 'OSWALD_PRO_VERSION' ) ) {
	/**
	 *
	 */
	$plugin_data = get_file_data(__FILE__, [
	    'Version' => 'Version',
	    'TextDomain' => 'Text Domain'
	], 'plugin');
	$plugin_version = $plugin_data['Version'];
	define( 'OSWALD_PRO_VERSION', $plugin_version );
	
}
require_once(plugin_dir_path( __FILE__ ).'/includes/aq_resizer.php');
require_once(plugin_dir_path( __FILE__ ).'/includes/modules/init.php');